;; Generated package description from cond-star.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "cond-star" "1.0.0.20250306.185816" "Extended form of `cond' construct" '((emacs "24.3")) :commit "fb33e3b4c79f8d922d9fe6e593dcc12c3c4b24eb" :url "https://elpa.gnu.org/packages/cond-star.html" :maintainer '("Richard Stallman" . "rms@gnu.org"))
